#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_GT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_GT_HPP_INCLUDED

#include <boost/simd/operator/include/functions/gt.hpp>

#endif
